toolchain-utils: Update list of toolchain boards for testing.

Update list to match availability in skylab.

BUG=chromium:948268
TEST=unit tests pass.

Change-Id: Ide1a67374e5282d7a06395b16b7ff0173f536c74
Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/third_party/toolchain-utils/+/1575792
Tested-by: Manoj Gupta <manojgupta@chromium.org>
Reviewed-by: Caroline Tice <cmtice@chromium.org>
Commit-Queue: Manoj Gupta <manojgupta@chromium.org>
diff --git a/buildbot_test_llvm.py b/buildbot_test_llvm.py
index 5141382..faa4440 100755
--- a/buildbot_test_llvm.py
+++ b/buildbot_test_llvm.py
@@ -39,52 +39,52 @@
 DATA_DIR = '/google/data/rw/users/mo/mobiletc-prebuild/waterfall-report-data/'
 
 # Information about Rotating Boards
 #  Board        Arch     Reference    Platform      Kernel
 #                        Board                      Version
 #  ------------ -------  ------------ ------------- -------
 #  cave         x86_64   glados       skylake-y     3.18
 #  daisy_skate  armv7    daisy        exynos-5250   3.8.11
 #  elm          aarch64  oak          mediatek-8173 3.18 arm32 userspace
 #  fizz         x86_64   fizz         kabylake-u/r  4.4.*
 #  gale         armv7                               3.18
 #  grunt        x86_64   grunt        stoney ridge  4.14.*
 #  guado_moblab x86_64                              3.14
 #  kevin        aarch64  gru          rockchip-3399 4.4.* arm32 userspace
 #  kevin64      aarch64  gru          rockchip-3399 4.4.* arm64 userspace
 #  lakitu       x86_64                              4.4.*
 #  lars         x86_64   kunimitsu    skylake-u     3.18
 #  leon         x86_64   slippy       haswell       3.8.11
 #  nautilus     x86_64   poppy        kabylake-y    4.4.*
 #  nyan_big     armv7    nyan         tegra         3.10.18
 #  peach_pit    armv7    peach        exynos-5420   3.8.11
 #  samus        x86_64   auron        broadwell     3.14
 #  snappy       x86_64   reef         apollo lake   4.4.*
 #  swanky       x86_64   rambi        baytrail      4.4.*
 #  terra        x86_64   strago       braswell      3.18
 #  veyron_jaq   armv7    veyron-pinky rockchip-3288 3.14
 #  whirlwind    armv7                               3.14
 
 TEST_BOARD = [
+    'asuka',
+    'atlas',
     'cave',
+    'coral',
+    'cyan',
     'daisy_skate',
-    # 'elm', tested by arm64-llvm-next-toolchain builder.
-    'fizz',
+    'elm',
+    # 'eve', tested by amd64-llvm-next-toolchain builder.
     'gale',
     'grunt',
     'guado_moblab',
-    'kevin',
+    # 'kevin', tested by arm64-llvm-next-toolchain builder.
     'kevin64',
     'lakitu',
-    'lars',
-    'leon',
-    'nautilus',
+    'peppy',
     'nyan_big',
     'peach_pit',
-    # 'samus', tested by amd64-llvm-next-toolchain builder.
-    'snappy',
-    'swanky',
-    'terra',
-    # 'veyron_jaq', tested by arm-llvm-next-toolchain builder.
+    'quawks',
+    'tidus',
+    # 'veyron_mighty', tested by arm-llvm-next-toolchain builder.
     'whirlwind',
 ]
@@ -39,52 +39,52 @@
 
 # Information about Rotating Boards
-#  Board        Arch     Reference    Platform      Kernel
-#                        Board                      Version
-#  ------------ -------  ------------ ------------- -------
-#  cave         x86_64   glados       skylake-y     3.18
-#  daisy_skate  armv7    daisy        exynos-5250   3.8.11
-#  elm          aarch64  oak          mediatek-8173 3.18 arm32 userspace
-#  fizz         x86_64   fizz         kabylake-u/r  4.4.*
-#  gale         armv7                               3.18
-#  grunt        x86_64   grunt        stoney ridge  4.14.*
-#  guado_moblab x86_64                              3.14
-#  kevin        aarch64  gru          rockchip-3399 4.4.* arm32 userspace
-#  kevin64      aarch64  gru          rockchip-3399 4.4.* arm64 userspace
-#  lakitu       x86_64                              4.4.*
-#  lars         x86_64   kunimitsu    skylake-u     3.18
-#  leon         x86_64   slippy       haswell       3.8.11
-#  nautilus     x86_64   poppy        kabylake-y    4.4.*
-#  nyan_big     armv7    nyan         tegra         3.10.18
-#  peach_pit    armv7    peach        exynos-5420   3.8.11
-#  samus        x86_64   auron        broadwell     3.14
-#  snappy       x86_64   reef         apollo lake   4.4.*
-#  swanky       x86_64   rambi        baytrail      4.4.*
-#  terra        x86_64   strago       braswell      3.18
-#  veyron_jaq   armv7    veyron-pinky rockchip-3288 3.14
-#  whirlwind    armv7                               3.14
+#  Board         Arch     Reference    Platform      Kernel
+#                         Board                      Version
+#  ------------  -------  ------------ ------------- -------
+#  asuka         x86_64   kunimitsu    skylake-u     3.18
+#  atlas         x86_64   poppy        kabylake-y    4.4.*
+#  cave          x86_64   glados       skylake-y     3.18
+#  coral         x86_64   reef         apollo lake   4.4.*
+#  cyan          x86_64   strago       braswell      3.18
+#  daisy_skate   armv7    daisy        exynos-5250   3.8.11
+#  elm           aarch64  oak          mediatek-8173 3.18 arm32 userspace
+#  eve           x86_64   poppy        kabylake-u/r  4.4.*
+#  gale          armv7                               3.18
+#  grunt         x86_64   grunt        stoney ridge  4.14.*
+#  guado_moblab  x86_64                              3.14
+#  kevin         aarch64  gru          rockchip-3399 4.4.* arm32 userspace
+#  kevin64       aarch64  gru          rockchip-3399 4.4.* arm64 userspace
+#  lakitu        x86_64                              4.4.*
+#  nyan_big      armv7    nyan         tegra         3.10.18
+#  peach_pit     armv7    peach        exynos-5420   3.8.11
+#  peppy         x86_64   slippy       haswell       3.8.11
+#  quawks        x86_64   rambi        baytrail      4.4.*
+#  tidus         x86_64   auron        broadwell     3.14
+#  veyron_mighty armv7    veyron-pinky rockchip-3288 3.14
+#  whirlwind     armv7                               3.14
 
 TEST_BOARD = [